@@ -16,7 +16,8 @@ from tempest import test
 from tempest import config
 from tempest.lib.common.utils import test_utils as utils
 
-from designate_tempest_plugin import clients
+from designate_tempest_plugin.services.dns.query.query_client import \
+    QueryClient
 
 
 CONF = config.CONF
@@ -76,6 +77,19 @@ class BaseDnsTest(test.BaseTestCase):
                         % cls.__name__)
             raise cls.skipException(skip_msg)
 
+    @classmethod
+    def setup_clients(cls):
+        super(BaseDnsTest, cls).setup_clients()
+        # The Query Client is not an OpenStack client which means
+        # we should not set it up through the tempest client manager.
+        # Set it up here so all tests have access to it.
+        cls.query_client = QueryClient(
+            nameservers=CONF.dns.nameservers,
+            query_timeout=CONF.dns.query_timeout,
+            build_interval=CONF.dns.build_interval,
+            build_timeout=CONF.dns.build_timeout,
+        )
+
     def assertExpected(self, expected, actual, excluded_keys):
         for key, value in six.iteritems(expected):
             if key not in excluded_keys:
@@ -110,6 +124,17 @@ class BaseDnsTest(test.BaseTestCase):
                               zone_client,
                               zone_id)
 
+    def wait_recordset_delete(self, recordset_client, zone_id,
+                              recordset_id, **kwargs):
+        self._delete_recordset(
+            recordset_client, zone_id, recordset_id, **kwargs)
+        utils.call_until_true(self._check_recordset_deleted,
+                              CONF.dns.build_timeout,
+                              CONF.dns.build_interval,
+                              recordset_client,
+                              zone_id,
+                              recordset_id)
+
     def _delete_zone(self, zone_client, zone_id, **kwargs):
         return utils.call_and_ignore_notfound_exc(zone_client.delete_zone,
                                                   zone_id, **kwargs)
@@ -118,28 +143,22 @@ class BaseDnsTest(test.BaseTestCase):
         return utils.call_and_ignore_notfound_exc(zone_client.show_zone,
                                                   zone_id) is None
 
+    def _delete_recordset(self, recordset_client, zone_id,
+                          recordset_id, **kwargs):
+        return utils.call_and_ignore_notfound_exc(
+            recordset_client.delete_recordset,
+            zone_id, recordset_id, **kwargs)
 
-class BaseDnsV1Test(BaseDnsTest):
-    """Base class for DNS V1 API tests."""
-
-    # Use the Designate V1 Client Manager
-    client_manager = clients.ManagerV1
-
-    @classmethod
-    def skip_checks(cls):
-        super(BaseDnsV1Test, cls).skip_checks()
-
-        if not CONF.dns_feature_enabled.api_v1:
-            skip_msg = ("%s skipped as designate v1 API is not available"
-                        % cls.__name__)
-            raise cls.skipException(skip_msg)
+    def _check_recordset_deleted(
+            self, recordset_client, zone_id, recordset_id):
+        return utils.call_and_ignore_notfound_exc(
+            recordset_client.show_recordset, zone_id, recordset_id) is None
 
 
 class BaseDnsV2Test(BaseDnsTest):
     """Base class for DNS V2 API tests."""
 
-    # Use the Designate V2 Client Manager
-    client_manager = clients.ManagerV2
+    all_projects_header = {'X-Auth-All-Projects': True}
 
     @classmethod
     def skip_checks(cls):
@@ -154,9 +173,6 @@ class BaseDnsV2Test(BaseDnsTest):
 class BaseDnsAdminTest(BaseDnsTest):
     """Base class for DNS Admin API tests."""
 
-    # Use the Designate Admin Client Manager
-    client_manager = clients.ManagerAdmin
-
     @classmethod
     def skip_checks(cls):
         super(BaseDnsAdminTest, cls).skip_checks()
